@@ -156,7 +156,7 @@ class EasySpreadsheet():
         return gc.open_by_url(spreadsheet_url)
 
     def get_easy_worksheet(self, worksheet_name, **argv):
-        return EasyWorksheet(self._sheet.worksheet(worksheet_name, **argv))
+        return EasyWorksheet(self._sheet.worksheet(worksheet_name), **argv)
 
     def get_worksheet(self, worksheet_name):
         return self._sheet.worksheet(worksheet_name)
